# FILE: sgi.tcl
#
# Configuration feature definitions for the configuration 'sgi'
#
# Editing instructions begin at "START EDIT HERE" below.

set config [Oc_Config RunPlatform]

if {![string match [string tolower [file rootname [file tail [info script]]]] \
        [$config GetValue platform_name]]} {
    error "Configuration cache file '[info script]' 
sourced by '[$config GetValue platform_name]'"
}

########################################################################
# START EDIT HERE
# In order to properly build, install, and run on your computing 
# platform, the OOMMF software must know certain features of your
# computing environment.  In this file are lines which set the value of 
# certain features of your computing environment.  Each line looks like:
#
# $config SetValue <feature> {<value>}
#
# where each <feature> is the name of some feature of interest,
# and <value> is the value which is assigned to that feature in a
# description of your computing environment.  Your task is to edit
# the values as necessary to properly describe your computing 
# environment.
#
# The character '#' at the beginning of a line is a comment character.
# It causes the contents of that line to be ignored.  To select
# among lines providing alternative values for a feature, uncomment the
# line containing the proper value.
#
# The features in this file are divided into three sections.  The first
# section (REQUIRED CONFIGURATION) includes features which require you 
# to provide a value.  The second section (OPTIONAL CONFIGURATION)
# includes features which have usable default values, but which you
# may wish to customize.  The third section (ADVANCED CONFIGURATION)
# contains features which you probably do not need or want to change
# without a good reason.
########################################################################
# REQUIRED CONFIGURATION

# Set the feature 'program_compiler_c++' to the program to run on this 
# platform to compile source code files written in the language C++ into 
# object files.  Select from the choices below.  If the compiler is not 
# in your path, be sure to use the whole pathname.  Also include any 
# options required to instruct your compiler to only compile, not link.  
#
# If your compiler is not listed below, additional features will
# have to be added in the ADVANCED CONFIGURATION section below to 
# describe to the OOMMF software how to operate your compiler.  Send
# e-mail to the OOMMF developers for assistance.
#
# SGI's MIPSpro C++ compiler
# <URL:http://www.sgi.com/developers/devtools/languages/mipspro.html>
# $config SetValue program_compiler_c++ {CC -32 -c}
#
# The GNU C++ compiler 'g++'
# <URL:http://www.gnu.org/software/gcc/gcc.html>
# WARNING: can't link against -o32 libraries.  ==> untested
#	Must build Tcl/Tk libraries as -n32
# $config SetValue program_compiler_c++ {g++ -c}
#
# MPI C++ compiler
$config SetValue program_compiler_c++ {mympiCC -32 -c -DUSE_MPI}
$config SetValue program_linker {mympiCC -32 -Wl,-LD_MSG:off=84}
$config SetValue platform_use_mpi 1
$config SetValue platform_mpirun_command {mpirun}
$config SetValue platform_mpirun_options {
    -np $env(OOMMF_MPI_PROC_COUNT) \
    {[format %s -machinefile [set env(OOMMF_MPI_MACHINE_FILE)]]} \
    $env(OOMMF_MPI_MACHINE_FILE) \
}

########################################################################
# OPTIONAL CONFIGURATION

# Set the feature 'path_directory_temporary' to the name of an existing 
# directory on your computer in which OOMMF software should write 
# temporary files.  All OOMMF users must have write access to this 
# directory.
#
$config SetValue path_directory_temporary {/tmp}

########################################################################
# ADVANCED CONFIGURATION

# Compiler option processing...
set ccbasename [file tail [lindex [$config GetValue program_compiler_c++] 0]]
# ...for SGI's compiler CC
$config SetValue program_compiler_c++_option_opt {format "\"-O%s\""}
$config SetValue program_compiler_c++_option_out {format "-o \"%s\""}
$config SetValue program_compiler_c++_option_src {format \"%s\"}
$config SetValue program_compiler_c++_option_inc {format "\"-I%s\""}
$config SetValue program_compiler_c++_option_warn {format "-fullwarn"}
$config SetValue program_compiler_c++_option_debug {format "-g"}
    $config SetValue program_compiler_c++_option_def {format "\"-D%s\""}

# Widest natively support floating point type
$config SetValue program_compiler_c++_typedef_realwide "double"

# Linker option processing...
set lbasename [file tail [lindex [$config GetValue program_linker] 0]]
# ...for SGI's CC as linker
$config SetValue program_linker_option_obj {format \"%s\"}
$config SetValue program_linker_option_out {format "-o \"%s\""}
$config SetValue program_linker_option_lib {format \"%s\"}
$config SetValue program_linker_uses_-L-l {1}
unset lbasename

# The program to run on this platform to create a single library file out
# of many object files.
# Use CC to get pre-linker run.
$config SetValue program_libmaker {CC -ar -o} 
# Option processing for ar
$config SetValue program_libmaker_option_obj {format \"%s\"}
$config SetValue program_libmaker_option_out {format \"%s\"}
unset ccbasename

# The absolute, native filename of the null device
$config SetValue path_device_null {/dev/null}

# A partial Tcl command (or script) which when completed by lappending
# a file name stem and evaluated returns the corresponding file name for
# an executable on this platform
$config SetValue script_filename_executable {format %s}

# A partial Tcl command (or script) which when completed by lappending
# a file name stem and evaluated returns the corresponding file name for
# an object file on this platform
$config SetValue script_filename_object {format %s.o}

# A partial Tcl command (or script) which when completed by lappending
# a file name stem and evaluated returns the corresponding file name for
# a static library on this platform
$config SetValue script_filename_static_library {format lib%s.a}

########################################################################
unset config

