# FILE: makerules.tcl
#
# This file controls the application 'pimake' by defining rules which
# describe how to build the applications and/or extensions produced by
# the source code in this directory.
#
# Verify that this script is being sourced by pimake
if {[llength [info commands MakeRule]] == 0} {
    error "'[info script]' must be evaluated by pimake"
}
#
########################################################################

MakeRule Define {
    -targets            doc
    -dependencies       [list userguide.pdf userguide.ps \
			        [file join userguide userguide.html]]
}

MakeRule Define {
    -targets            [file join userguide userguide.html]
    -dependencies       userguide.dvi
    -script	{
	Oc_Exec Foreground latex2html userguide.tex
	file copy -force contents.gif userguide
	file copy -force oommficon.gif userguide
    }
}

MakeRule Define {
    -targets            userguide.ps
    -dependencies       userguide.dvi
    -script		{
			DeleteFiles userguide.ps
			Oc_Exec Foreground dvips -f userguide.dvi > userguide.ps
			}
}

MakeRule Define {
    -targets            userguide.dvi
    -dependencies       [glob -nocomplain *.tex]
    -script		{
			eval DeleteFiles [glob -nocomplain *.aux]
			eval DeleteFiles [glob -nocomplain *.bbl]
			eval DeleteFiles [glob -nocomplain *.ind]
			eval DeleteFiles [glob -nocomplain *.toc]
			Oc_Exec Foreground latex userguide
			Oc_Exec Foreground bibtex userguide
			Oc_Exec Foreground latex userguide
                        Oc_Exec Foreground makeindex userguide.idx
			Oc_Exec Foreground latex userguide
			}
}

MakeRule Define {
    -targets            userguide.pdf
    -dependencies       [glob -nocomplain *.tex]
    -script		{
			eval DeleteFiles [glob -nocomplain *.aux]
			eval DeleteFiles [glob -nocomplain *.bbl]
			eval DeleteFiles [glob -nocomplain *.ind]
			eval DeleteFiles [glob -nocomplain *.toc]
			Oc_Exec Foreground pdflatex userguide
			Oc_Exec Foreground bibtex userguide
			Oc_Exec Foreground pdflatex userguide
                        Oc_Exec Foreground makeindex userguide.idx
			Oc_Exec Foreground pdflatex userguide
			}
}

MakeRule Define {
    -targets            maintainer-clean
    -dependencies       distclean
    -script		{
			eval DeleteFiles [glob -nocomplain *.aux]
			eval DeleteFiles [glob -nocomplain *.bbl]
			eval DeleteFiles [glob -nocomplain *.blg]
			eval DeleteFiles [glob -nocomplain *.dvi]
			eval DeleteFiles [glob -nocomplain *.idx]
			eval DeleteFiles [glob -nocomplain *.ind]
			eval DeleteFiles [glob -nocomplain *.ilg]
			eval DeleteFiles [glob -nocomplain *.log]
			eval DeleteFiles [glob -nocomplain *.out]
			eval DeleteFiles [glob -nocomplain *.toc]
			DeleteFiles userguide userguide.ps userguide.pdf
			}
}
 
MakeRule Define {
    -targets		upgrade
    -script		{DeleteFiles biblio.tex contents_motif.gif}
}

